@@ -9,6 +9,16 @@ import warnings
 from .connect import Connection
 
 class GoogleSearchConsole:
+    """
+    Google API Wrapper for Google Search Console
+    REMEMBER your 'client_secret.json' file in your PATH
+
+    Parameters
+    auth: googleapiclient.discovery.Resource object 
+            created from the Connection class by default
+            no need to mess with this
+    """
+
     def __init__(self, auth = Connection().gsc()):
         
         self.auth = auth
