@@ -1,5 +1,5 @@
 from .connect import Connection
-from pandas import DataFrame
+from pandas import DataFrame, Series
 
 
 class GoogleSheets:
@@ -16,12 +16,20 @@ class GoogleSheets:
     Uses the pygsheets library
     https://pygsheets.readthedocs.io/en/stable/index.html
     """
-    def __init__(self, url:str, auth = Connection().pygsheets()):
+    def __init__(self, url:str = None, auth = Connection().pygsheets()):
         self.url = url
-        self.id = self.__get_id()
         self.auth = auth
-        self.wb = self.auth.open_by_url(self.url)
-        self.sheet = self.wb.sheet1
+        if self.url is not None:
+            self.id = self.__get_id()
+            self.wb = self.auth.open_by_url(self.url)
+            self.sheet = self.wb.sheet1
+
+    def create_sheet(self,title,folder = None,template = None):
+        """
+        create a new worksheet and set it to the active workbook
+        """
+        self.wb = self.auth.create(title,folder = folder,template = template)
+        # self.set_sheet('Sheet1')
 
     def __get_id(self) -> str:
         """
@@ -60,6 +68,8 @@ class GoogleSheets:
         """
         if isinstance(df,DataFrame):
             self.sheet.set_dataframe(df,start,copy_index=index,copy_head=header,extend=extend)
+        elif isinstance(df,Series):
+            self.sheet.set_dataframe(DataFrame(df),start,copy_index=index,copy_head=header,extend=extend)
         else:
             raise TypeError("Please pass in a pd.DataFrame to save to Google Sheets")
 
@@ -114,7 +124,7 @@ class GoogleSheets:
         """
         delete a tab named sheet_name from your workbook
         """
-        self.wb.del_worksheet(sheet_name)
+        self.wb.del_worksheet(self.wb.worksheet('title',sheet_name))
 
     def share(
                 self, 
